@@ -496,11 +496,11 @@ UnityObjectFactory.prototype = {
     _get: function(aWindow) {
         aWindow = FindToplevelContentWindow(aWindow);
 
-        if (!this._windows.has(aWindow.navigator)) {
-            this._windows.set(aWindow.navigator, { unity: new UnityObject(this.uwa, this.service, this.contextManager, aWindow),
+        if (!this._windows.has(aWindow.document)) {
+            this._windows.set(aWindow.document, { unity: new UnityObject(this.uwa, this.service, this.contextManager, aWindow),
                                                    webkitNotifications: new WebkitNotifications(this.uwa, this.libnotify, aWindow) });
         }
-        return this._windows.get(aWindow.navigator);
+        return this._windows.get(aWindow.document);
     },
 
     getForWindow: function(aWindow) {
@@ -512,7 +512,7 @@ UnityObjectFactory.prototype = {
     },
 
     getExistingForWindow: function(aWindow) {
-        if (!this._windows.has(aWindow.navigator))
+        if (!this._windows.has(aWindow.document))
             return null;
         return this._get(aWindow).unity;
     }
